<?php
defined( 'ABSPATH' ) or die( 'No script kiddies please!!' );
if ( !class_exists( 'STD_Hooks' ) ) {

    class STD_Hooks extends STD_Library {

        function __construct() {
            add_action( 'template_redirect', array( $this, 'form_preview' ) );
            add_action( 'template_redirect', array( $this, 'verify_subscription_confirmation' ) );
            add_action( 'std_end_form_process', array( $this, 'process_third_party_subscriptions' ), 10, 2 );
            add_action( 'wp_footer', array( $this, 'add_popup_wrapper' ) );
            add_action( 'template_redirect', array( $this, 'unsubscribe_action' ) );
        }

        function form_preview() {
            if ( isset( $_GET['std_preview'], $_GET['_wpnonce'] ) && $_GET['std_preview'] && wp_verify_nonce( $_GET['_wpnonce'], 'std_form_preview_nonce' ) && is_user_logged_in() ) {
                wp_enqueue_style( 'std-preview', STD_URL . 'css/std-preview.css', array(), STD_VERSION );
                include(STD_PATH . 'inc/views/frontend/form-preview.php');
                die();
            }
        }

        function process_third_party_subscriptions( $form_data, $form_details ) {
            if ( !empty( $form_data['std_email'] ) ) {
                if ( !empty( $form_data['std_name'] ) ) {
                    $name_array = explode( ' ', $form_data['std_name'] );
                    $fname = $name_array[0];
                    $lname = (count( $name_array ) > 1) ? end( $name_array ) : '';
                } else {
                    $fname = '';
                    $lname = '';
                }
                $third_party_flag = true;
                if ( !empty( $form_details['form']['gdpr_agreement']['show'] ) ) {
                    if ( empty( $form_data['std_gdpr_agreement'] ) ) {
                        $third_party_flag = false;
                    }
                }
                if ( $third_party_flag ) {
                    if ( !empty( $form_details['general']['mailchimp_id'] ) ) {
                        $post_parameters = array( 'members' => array( array( 'email_address' => $form_data['std_email'], 'status' => 'subscribed', 'merge_fields' => array( 'FNAME' => $fname, 'LNAME' => $lname ) ) ), 'update_existing' => true );
                        /**
                         * Filters parameters being sent to Maichimp
                         *
                         * @param array $post_parameters
                         * @param array $form_data
                         * @param array $form_details
                         */
                        $post_parameters = apply_filters( 'std_mc_post_parameters', $post_parameters, $form_data, $form_details );
                        foreach ( $form_details['general']['mailchimp_id'] as $mailchimp_id ) {
                            $this->subscribe_to_mailchimp( $mailchimp_id, $post_parameters );
                        }
                    }
                    if ( !empty( $form_details['general']['constant_contact_id'] ) ) {
                        $post_parameters = array(
                            'confirmed' => true,
                            'email_addresses' =>
                            array(
                                array(
                                    'email_address' => $form_data['std_email'],
                                    'confirm_status' => 'NO_CONFIRMATION_REQUIRED'
                                ),
                            ),
                            'first_name' => $fname,
                            'last_name' => $lname,
                        );


                        /**
                         * std_cc_post_parameters filters parameters being sent to Constant Contact
                         *
                         * @param array $post_parameters
                         * @param array $form_data
                         * @param array $form_details
                         */
                        $post_parameters = apply_filters( 'std_cc_post_parameters', $post_parameters, $form_data, $form_details );
                        foreach ( $form_details['general']['constant_contact_id'] as $constant_contact_id ) {
                            $post_parameters['lists'][] = array( 'id' => $constant_contact_id );
                        }
                        $this->subscribe_to_cc( $constant_contact_id, $post_parameters );
                    }
                }
            }
        }

        function verify_subscription_confirmation() {
            if ( isset( $_GET['std_subscription_confirmation'], $_GET['confirmation_verification_key'] ) ) {
                $confirmation_verification_key = sanitize_text_field( $_GET['confirmation_verification_key'] );
                if ( !empty( $_COOKIE['std_email'] ) && !empty( $_COOKIE['std_alias'] ) ) {
                    $subscriber_email = sanitize_email( $_COOKIE['std_email'] );
                    $subscriber_name = (!empty( $_COOKIE['std_name'] )) ? sanitize_text_field( $_COOKIE['std_name'] ) : '';
                    $std_gdpr_agreement = (!empty( $_COOKIE['std_gdpr_agreement'] )) ? sanitize_text_field( $_COOKIE['std_gdpr_agreement'] ) : '';
                    if ( md5( $subscriber_email ) == $confirmation_verification_key ) {
                        $form_alias = sanitize_text_field( $_COOKIE['std_alias'] );
                        $form_row = $this->get_form_row_by_alias( $form_alias );
                        $form_details = maybe_unserialize( $form_row->form_details );
                        $form_data['std_email'] = $subscriber_email;
                        $form_data['std_name'] = $subscriber_name;
                        $form_data['std_gdpr_agreement'] = $std_gdpr_agreement;
                        include(STD_PATH . '/inc/cores/download-email.php');
                        echo $this->sanitize_html( $form_details['general']['optin_confirmation_message'] );
                        die();
                    }
                }
            }
        }

        function add_popup_wrapper() {
            ?>
            <div class="std-temp-popup-wrapper"></div>
            <?php
        }

        function unsubscribe_action() {
            if ( !empty( $_GET['std_action'] ) && $_GET['std_action'] == 'unsubscribe' && !empty( $_GET['unsubscribe_key'] ) ) {
                $unsubscribe_key = sanitize_text_field( $_GET['unsubscribe_key'] );

                if ( $this->is_valid_encryption_key( $unsubscribe_key ) ) {
                    global $wpdb;
                    $wpdb->delete( STD_SUBSCRIBERS_TABLE, array( 'subscriber_encryption_key' => $unsubscribe_key ), array( '%s' ) );
                    $std_settings = get_option( 'std_settings' );
                    $unsubscribe_message = (!empty( $std_settings['extra']['unsubscribe_message'] )) ? $std_settings['extra']['unsubscribe_message'] : $this->default_unsubscribe_message();
                    echo $this->sanitize_html( $unsubscribe_message );
                    die();
                }
            }
        }

    }

    new STD_Hooks();
}
